@@ -138,7 +138,6 @@ main (int argc, char **argv)
 {
 	GMainLoop *loop;
 	SoupServer *server;
-	guint port;
 	SoupURI *base_uri;
 	int ret;
 
@@ -149,15 +148,13 @@ main (int argc, char **argv)
 							 (guchar *)full_response->data,
 							 full_response->length);
 
-	server = soup_test_server_new (FALSE);
+	server = soup_test_server_new (SOUP_TEST_SERVER_DEFAULT);
 	soup_server_add_handler (server, NULL,
 				 server_callback, NULL, NULL);
-	port = 	soup_server_get_port (server);
 
 	loop = g_main_loop_new (NULL, TRUE);
 
-	base_uri = soup_uri_new ("http://127.0.0.1");
-	soup_uri_set_port (base_uri, port);
+	base_uri = soup_test_server_get_uri (server, "http", NULL);
 
 	g_test_add_data_func ("/streaming/chunked", base_uri, do_chunked_test);
 	g_test_add_data_func ("/streaming/content-length", base_uri, do_content_length_test);
